@@ -105,7 +105,7 @@ module VagrantPlugins
                 b3.use ForwardPorts
                 b3.use PrepareNFSSettings
                 b3.use ShareFolders
-             end
+              end
             end
           end
         end
@@ -118,7 +118,7 @@ module VagrantPlugins
           b.use ConfigValidate
           b.use ClearForwardedPorts
           b.use Call, IsCreated do |env, b2|
-            if !env[:result]
+            unless env[:result]
               b2.use MessageNotCreated
               next
             end
@@ -128,7 +128,7 @@ module VagrantPlugins
             end
 
             b2.use Call, IsRunning do |env2, b3|
-              next if !env2[:result]
+              next unless env2[:result]
 
               # VM is running, halt it.
               b3.use HaltDomain
@@ -142,7 +142,7 @@ module VagrantPlugins
       def self.action_reload
         Vagrant::Action::Builder.new.tap do |b|
           b.use Call, IsCreated do |env, b2|
-            if !env[:result]
+            unless env[:result]
               b2.use MessageNotCreated
               next
             end
@@ -168,15 +168,11 @@ module VagrantPlugins
         Vagrant::Action::Builder.new.tap do |b|
           b.use ConfigValidate
           b.use Call, IsCreated do |env, b2|
-            if !env[:result]
+            unless env[:result]
               # Try to remove stale volumes anyway
               b2.use SetNameOfDomain
-              if env[:machine].config.vm.box
-                b2.use RemoveStaleVolume
-              end
-              if !env[:result]
-                b2.use MessageNotCreated
-              end
+              b2.use RemoveStaleVolume if env[:machine].config.vm.box
+              b2.use MessageNotCreated unless env[:result]
 
               next
             end
@@ -195,13 +191,13 @@ module VagrantPlugins
         Vagrant::Action::Builder.new.tap do |b|
           b.use ConfigValidate
           b.use Call, IsCreated do |env, b2|
-            if !env[:result]
+            unless env[:result]
               b2.use MessageNotCreated
               next
             end
 
             b2.use Call, IsRunning do |env2, b3|
-              if !env2[:result]
+              unless env2[:result]
                 b3.use MessageNotRunning
                 next
               end
@@ -217,13 +213,13 @@ module VagrantPlugins
         Vagrant::Action::Builder.new.tap do |b|
           b.use ConfigValidate
           b.use Call, IsCreated do |env, b2|
-            if !env[:result]
+            unless env[:result]
               b2.use MessageNotCreated
               next
             end
 
             b2.use Call, IsRunning do |env2, b3|
-              if !env2[:result]
+              unless env2[:result]
                 b3.use MessageNotRunning
                 next
               end
@@ -241,13 +237,13 @@ module VagrantPlugins
         Vagrant::Action::Builder.new.tap do |b|
           b.use ConfigValidate
           b.use Call, IsCreated do |env, b2|
-            if !env[:result]
+            unless env[:result]
               b2.use MessageNotCreated
               next
             end
 
             b2.use Call, IsRunning do |env2, b3|
-              if !env2[:result]
+              unless env2[:result]
                 b3.use MessageNotRunning
                 next
               end
@@ -263,13 +259,13 @@ module VagrantPlugins
         Vagrant::Action::Builder.new.tap do |b|
           b.use ConfigValidate
           b.use Call, IsCreated do |env, b2|
-            if !env[:result]
+            unless env[:result]
               b2.use MessageNotCreated
               next
             end
 
             b2.use Call, IsSuspended do |env2, b3|
-              if !env2[:result]
+              unless env2[:result]
                 b3.use MessageNotSuspended
                 next
               end
@@ -291,13 +287,13 @@ module VagrantPlugins
         Vagrant::Action::Builder.new.tap do |b|
           b.use ConfigValidate
           b.use Call, IsCreated do |env, b2|
-            if !env[:result]
+            unless env[:result]
               b2.use MessageNotCreated
               next
             end
 
             b2.use Call, IsRunning do |env2, b3|
-              if !env2[:result]
+              unless env2[:result]
                 b3.use MessageNotRunning
                 next
               end
@@ -305,7 +301,6 @@ module VagrantPlugins
               b3.use SSHRun
             end
           end
-
         end
       end
 
@@ -351,7 +346,7 @@ module VagrantPlugins
       autoload :WaitTillUp, action_root.join('wait_till_up')
       autoload :PrepareNFSValidIds, action_root.join('prepare_nfs_valid_ids')
 
-      autoload :SSHRun,  'vagrant/action/builtin/ssh_run'
+      autoload :SSHRun, 'vagrant/action/builtin/ssh_run'
       autoload :HandleBox, 'vagrant/action/builtin/handle_box'
       autoload :SyncedFolders, 'vagrant/action/builtin/synced_folders'
       autoload :SyncedFolderCleanup, 'vagrant/action/builtin/synced_folder_cleanup'
