@@ -33,7 +33,6 @@ module VagrantPlugins
         error_key(:image_upload_error)
       end
 
-
       # Box exceptions
       class NoBoxVolume < VagrantLibvirtError
         error_key(:no_box_volume)
@@ -51,7 +50,6 @@ module VagrantPlugins
         error_key(:wrong_box_format)
       end
 
-
       # Fog libvirt exceptions
       class FogError < VagrantLibvirtError
         error_key(:fog_error)
@@ -110,6 +108,10 @@ module VagrantPlugins
         error_key(:tunnel_port_not_defined)
       end
 
+      class ManagementNetworkRequired < VagrantLibvirtError
+        error_key(:management_network_required)
+      end
+
       # Other exceptions
       class InterfaceSlotNotAvailable < VagrantLibvirtError
         error_key(:interface_slot_not_available)
@@ -142,7 +144,6 @@ module VagrantPlugins
       class DeleteSnapshotError < VagrantLibvirtError
         error_key(:delete_snapshot_error)
       end
-
     end
   end
 end
