@@ -1,14 +1,13 @@
-require "ostruct"
-require "pathname"
+require 'ostruct'
+require 'pathname'
 
 class EnvironmentHelper
-
   attr_writer :domain_name
 
   attr_accessor :random_hostname, :name, :default_prefix
 
   def [](value)
-    self.send(value.to_sym)
+    send(value.to_sym)
   end
 
   def cpus
@@ -34,15 +33,14 @@ class EnvironmentHelper
   end
 
   def root_path
-    Pathname.new("./spec/support/foo")
+    Pathname.new('./spec/support/foo')
   end
 
   def domain_name
-    #noop
+    # noop
   end
 
   def libvirt_compute
     OpenStruct.new(servers: [])
   end
-
 end
