@@ -1,11 +1,11 @@
-require "spec_helper"
+require 'spec_helper'
 
 describe VagrantPlugins::ProviderLibvirt::Action::SetNameOfDomain do
   before :each do
     @env = EnvironmentHelper.new
   end
 
-  it "builds unique domain name" do
+  it 'builds unique domain name' do
     @env.random_hostname = true
     dmn = VagrantPlugins::ProviderLibvirt::Action::SetNameOfDomain.new(Object.new, @env)
     first  = dmn.build_domain_name(@env)
@@ -13,8 +13,8 @@ describe VagrantPlugins::ProviderLibvirt::Action::SetNameOfDomain do
     first.should_not eq(second)
   end
 
-  it "builds simple domain name" do
-    @env.default_prefix= 'pre'
+  it 'builds simple domain name' do
+    @env.default_prefix = 'pre'
     dmn = VagrantPlugins::ProviderLibvirt::Action::SetNameOfDomain.new(Object.new, @env)
     dmn.build_domain_name(@env).should eq('pre_')
   end
